/**
 * Copyright (C) 2015 - 2018 Kosmos contact@kosmos.fr
 *
 * Projet: blog
 * Version: 1.07.00-BETA-01
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.kosmos.blog.processus;

import org.apache.commons.lang3.StringUtils;

import com.jsbsoft.jtf.core.InfoBean;
import com.jsbsoft.jtf.core.LangueUtil;
import com.kosmos.blog.om.Articleblog;
import com.kosmos.blog.om.Blog;
import com.kosmos.service.impl.ServiceManager;
import com.univ.objetspartages.bean.RubriqueBean;
import com.univ.objetspartages.om.StructureModele;
import com.univ.objetspartages.processus.ControleurUniv;
import com.univ.objetspartages.processus.SaisieFiche;
import com.univ.objetspartages.services.ServiceRubrique;
import com.univ.objetspartages.services.ServiceStructure;

/**
 * Processus de gestion des articleblogs.
 */
public class SaisieArticleblog extends SaisieFiche {

    private static final String ECRAN_RECHERCHE = "RECHERCHE";

    private static final String ECRAN_PRINCIPAL = "PRINCIPAL";

    private static final String ECRAN_CONFIRMATION = "CONFIRMATION";

    private Articleblog articleblog = null;

    /**
     * Constructeur.
     *
     * @param infoBean
     */
    public SaisieArticleblog(final InfoBean infoBean) {
        super(infoBean);
    }

    /**
     * Point d'entree du processus.
     */
    @Override
    public boolean traiterAction() throws Exception {
        infoBean.set("CODE_OBJET", "9130");
        articleblog = new Articleblog();
        articleblog.init();
        traiterActionParDefaut(articleblog);
        infoBean.set("NOM_ONGLET", "articleblog");
        return etat == FIN;
    }

    /**
     * Affichage de l'ecran des criteres de recherche d'un(e) articleblog.
     */
    @Override
    protected void preparerRECHERCHE() throws Exception {
        ecranLogique = ECRAN_RECHERCHE;
        infoBean.set("LISTE_LANGUES", LangueUtil.getListeLangues(this.getLocale()));
    }

    /**
     * Affichage de l'ecran de saisie d'un(e) articleblog.
     */
    @Override
    protected void preparerPRINCIPAL() throws Exception {
        ecranLogique = ECRAN_PRINCIPAL;
        infoBean.set("ID_ARTICLEBLOG", articleblog.getIdArticleblog().toString());
        infoBean.set("TITRE", articleblog.getTitre());
        infoBean.set("CHAPEAU", articleblog.getChapeau());
        infoBean.set("CONTENU", articleblog.getContenu());
        infoBean.set("KEYWORDS", articleblog.getKeywords());
        infoBean.set("CODE_RUBRIQUE", articleblog.getCodeRubrique());
        final ServiceRubrique serviceRubrique = ServiceManager.getServiceForBean(RubriqueBean.class);
        final RubriqueBean rubriqueBean = serviceRubrique.getRubriqueByCode(articleblog.getCodeRubrique());
        String rubriqueLabel = StringUtils.EMPTY;
        if (rubriqueBean != null) {
            rubriqueLabel = rubriqueBean.getIntitule();
        }
        infoBean.set("LIBELLE_CODE_RUBRIQUE", rubriqueLabel);
        infoBean.set("CODE_RATTACHEMENT", articleblog.getCodeRattachement());
        final ServiceStructure serviceStructure = ServiceManager.getServiceForBean(StructureModele.class);
        infoBean.set("LIBELLE_CODE_RATTACHEMENT", serviceStructure.getDisplayableLabel(articleblog.getCodeRattachement(), articleblog.getLangue()));
        infoBean.set("LIBELLE_AFFICHABLE", articleblog.getLibelleAffichable());
        if (infoBean.get("SAISIE_FRONT") == null) {
            infoBean.set("SOUS_ONGLET", "PRINCIPAL"); // onglet par defaut
        }
        infoBean.set("LISTE_BLOGS", Blog.getBlogs(this));
        ControleurUniv.preparerPRINCIPAL(infoBean, articleblog, this);
    }

    /**
     * Traite l'ecran de saisie d'une fiche.
     */
    @Override
    protected void traiterPRINCIPAL() throws Exception {
        // chargement de l'objet
        if (infoBean.getEtatObjet().equals(InfoBean.ETAT_OBJET_CREATION)) {
            articleblog.init();
        } else {
            articleblog.setIdArticleblog(new Long(infoBean.getString("ID_ARTICLEBLOG")));
            articleblog.retrieve();
        }
        // changement d'onglet
        if (action.equals(InfoBean.ACTION_ONGLET)) {
            infoBean.set("SOUS_ONGLET", infoBean.getString("SOUS_ONGLET_DEMANDE"));
        }
        // validation de l'ecran
        else if (action.equals(InfoBean.ACTION_ENREGISTRER)) {
            alimenteDonneesCreation(articleblog, false);
            articleblog.setTitre((String) infoBean.get("TITRE"));
            articleblog.setChapeau((String) infoBean.get("CHAPEAU"));
            articleblog.setContenu((String) infoBean.get("CONTENU"));
            articleblog.setKeywords((String) infoBean.get("KEYWORDS"));
            articleblog.setCodeRubrique(infoBean.getString("CODE_RUBRIQUE"));
            articleblog.setCodeRattachement(infoBean.getString("CODE_RATTACHEMENT"));
        }
        ecranLogique = ControleurUniv.traiterPRINCIPAL(infoBean, articleblog, this);
        if (infoBean.get("SAISIE_FRONT") != null) {
            infoBean.set("URL_REDIRECT", "");
            infoBean.set("OBJET", "blog");
            infoBean.set("CODE", articleblog.getBlog().getCode());
            ecranLogique = ECRAN_CONFIRMATION;
        }
        if (ecranLogique.length() == 0) {
            etat = FIN;
        }
    }
}
